#!/usr/bin/env python
# coding: utf-8

from setuptools import setup, find_packages

setup(
    name='easytexminer',
    version='0.0',
    author='Haojie Pan,Minghui Qiu',
    author_email='haojie.phj@alibaba-inc.com,minghui.qmh@alibaba-inc.com',
    url='',
    description=u'EasyTexMiner (An easy-to-use Text Mining Toolkits)',
    packages=find_packages(),
    install_requires=[]
)